// workspace.cpp
//
// a shelltool for querying/setting/incrementing the current workspace #
//
// by daniel sandler <dsandler@stardot.com>
// http://www.stardot.com/~dsandler/soft/beos/

/*
Copyright (c) 2001, Daniel Sandler <dsandler@stardot.com>
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

  * Redistributions of source code must retain the above copyright notice, this
    list of conditions and the following disclaimer. 

  * Redistributions in binary form must reproduce the above copyright notice,
    this list of conditions and the following disclaimer in the documentation
    and/or other materials provided with the distribution. 

  * The names of its contributors may not be used to endorse or promote
    products derived from this software without specific prior written
    permission. 

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE FOR ANY
DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

*/

#include <Application.h>
#include <InterfaceDefs.h>

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

// void activate_workspace(int32 workspace) 

// int32 current_workspace(void)

#define USAGE_TEXT "usage: ws get\n\
       ws set <workspace#>\n\
       ws count\n\
       ws ++\n\
       ws --\n\
       ws += <num>\n\
       ws -= <num>\n"

int main(int argc, char ** argv) {
	// printf("%d", argc);
	
	BApplication app("application/x-vnd.Be-WS");
	
	if ( (argc >= 2) && (strcasecmp(argv[1], "-h") == 0) ) {
		printf(USAGE_TEXT);
		exit(-1);
	} else if ( (argc == 2) && (strcasecmp(argv[1], "get") == 0) ) {
		printf("%d\n", (1+current_workspace()));
	} else if ( (argc == 3) && (strcasecmp(argv[1], "set") == 0) ) {
		int32 workspace = atoi(argv[2]);
		if (workspace>=0) {
			activate_workspace(workspace-1);
			int32 newws = current_workspace();
			exit((newws == (workspace-1))?0:1); // ok?
		} else {
			printf("error: not a workspace: %s\n", argv[2]);
			exit(-1);
		}
	} else if ( (argc == 2) && (strcasecmp(argv[1], "count") == 0) ) {
		printf("%d\n", (count_workspaces()));
	} else if ( (argc == 2) && (strcmp(argv[1], "++") == 0)) {
		int32 old = current_workspace();
		activate_workspace(current_workspace()+1);
		int32 newws = current_workspace();
		exit((newws!=old)?0:1);
	} else if ( (argc == 3) && (strcmp(argv[1], "+=") == 0)) {
		int32 old = current_workspace();
		activate_workspace(current_workspace()+atoi(argv[2]));
		int32 newws = current_workspace();
		exit((newws!=old)?0:1);
	} else if ( (argc == 2) && (strcmp(argv[1], "--") == 0)) {
		int32 old = current_workspace();
		activate_workspace(current_workspace()-1);
		int32 newws = current_workspace();
		exit((newws!=old)?0:1);
	} else if ( (argc == 3) && (strcmp(argv[1], "-=") == 0)) {
		int32 old = current_workspace();
		activate_workspace(current_workspace()-atoi(argv[2]));
		int32 newws = current_workspace();
		exit((newws!=old)?0:1);
	} else {
		printf(USAGE_TEXT);
		exit(-1);
	}
	exit(0);
}

